==> moodle-1.4.3.tgz: moodle/lang/cs/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.4 (2004083100)


$string['about'] = 'O tomto editoru';
$string['absbottom'] = 'pln dol (absbottom)';
$string['middle'] = 'Pesn uprosted (middle)';
$string['address'] = 'Adresa';
$string['alignment'] = 'Zarovnn';
$string['alternatetext'] = 'Alternativn text';
$string['anchorhelp'] = 'Tmto vytvte pouze nvt. Stle sem muste run nadefinovat odkaz.';
$string['anchorname'] = 'Nzev nvt';
$string['anchors'] = 'Nvt';
$string['baseline'] = 'a (baseline)';
$string['bold'] = 'Tun';
$string['borderthickness'] = 'Tlouka ohranien';
$string['bottom'] = 'Dol (bottom)';
$string['browse'] = 'Prochzet';
$string['cancel'] = 'Storno';
$string['cellpadding'] = 'Vnitn okraj bunk';
$string['cellspacing'] = 'Vzdlenost mezi bukami';
$string['choosechar'] = 'Vyberte znak';
$string['chooseicon'] = 'Vyberte ikonu k vloen';
$string['close'] = 'Zavt';
$string['cols'] = 'Sloupc';
$string['copy'] = 'Koprovat vbr';
$string['createanchor'] = 'Vytvoit nvt';
$string['createfolder'] = 'Vytvoit sloku';
$string['createlink'] = 'Vloit odkaz';
$string['cut'] = 'Vyjmout vbr';
$string['delete'] = 'Odstranit';
$string['filebrowser'] = 'Prohle soubor';
$string['forecolor'] = 'Barva psma';
$string['fullscreen'] = 'Na celou obrazovku';
$string['heading'] = 'Nadpis';
$string['height'] = 'Vka';
$string['hilitecolor'] = 'Barva zvraznn';
$string['horizontal'] = 'Vodorovn';
$string['horizontalrule'] = 'Vodorovn ra';
$string['htmlmode'] = 'Pepnout na HTML zdroj';
$string['imageurl'] = 'URL obrzku';
$string['indent'] = 'Zvtit odsazen';
$string['insertchar'] = 'Vloit specln znak';
$string['insertimage'] = 'Vloit obrzek';
$string['insertlink'] = 'Vloit odkaz';
$string['insertsmile'] = 'Vloit smajlk';
$string['inserttable'] = 'Vloit tabulku';
$string['italic'] = 'Kurzva';
$string['justifycenter'] = 'Zarovnat na sted';
$string['justifyfull'] = 'Zarovnat do bloku';
$string['justifyleft'] = 'Zarovnat vlevo';
$string['justifyright'] = 'Zarovnat vpravo';
$string['layout'] = 'Vzhled';
$string['left'] = 'Vlevo';
$string['lefttoright'] = 'Zleva doprava';
$string['linkproperties'] = 'Vlastnosti odkazu';
$string['linktarget'] = 'Kde otevt';
$string['linktargetblank'] = 'V novm okn';
$string['linktargetnone'] = 'Bez uren';
$string['linktargetother'] = 'Jinde (zatm nefunguje)';
$string['linktargetself'] = 'Ve stvajcm rmci';
$string['linktargettop'] = 'Ve stejnm okn';
$string['linktitle'] = 'Titulek';
$string['linkurl'] = 'URL';
$string['middle'] = 'Uprosted (middle)';
$string['minimize'] = 'Minimalizovat editor';
$string['move'] = 'Pesunout';
$string['normal'] = 'Normln';
$string['notimage'] = 'Vybran soubor nen obrzek. Prosm, vyberte jin soubor.';
$string['notset'] = 'Nenastaveno';
$string['ok'] = 'OK';
$string['orderedlist'] = 'slovan seznam';
$string['outdent'] = 'Zmenit odsazen';
$string['paste'] = 'Vloit ze schrnky';
$string['path'] = 'HTML cesta';
$string['percent'] = 'Procent';
$string['pixels'] = 'Pixel';
$string['popupeditor'] = 'Zvtit editor';
$string['preformatted'] = 'Pedformtovan';
$string['preview'] = 'Nhled';
$string['properties'] = 'Vlastnosti';
$string['redo'] = 'Opakovat posledn akci';
$string['removelink'] = 'Odstranit odkaz';
$string['rename'] = 'Pejmenovat';
$string['right'] = 'Vpravo';
$string['righttoleft'] = 'Zprava doleva';
$string['rows'] = 'dk';
$string['selectcolor'] = 'Vbr barvy';
$string['selection'] = 'Vbr';
$string['showhelp'] = 'Npovda k pouvn editoru';
$string['size'] = 'Velikost';
$string['spacing'] = 'Vzdlenost od textu';
$string['strikethrough'] = 'Pekrtnout';
$string['subscript'] = 'Doln index';
$string['superscript'] = 'Horn index';
$string['textindicator'] = 'Stvajc styl';
$string['textmode'] = 'Jste v TEXTOVM reimu. Stisknutm tlatka [<>] se vrtte do reimu WYSIWYG.';
$string['texttop'] = 'Text nahoe (texttop)';
$string['top'] = 'Nahoru (top)';
$string['type'] = 'Typ';
$string['underline'] = 'Podtrhnout';
$string['undo'] = 'Vrtit posledn akci (UNDO)';
$string['unorderedlist'] = 'Odrkov seznam';
$string['upload'] = 'Nahrt';
$string['vertical'] = 'Svisle';
$string['width'] = 'ka';
$string['wordclean'] = 'Vyistit HTML z Wordu';
$string['zip'] = 'ZIP';

?>

==> moodle-1.5.3.tgz: moodle/lang/cs/editor.php <==
<?PHP // $Id$ 
      // editor.php - created with Moodle 1.5 + (2005060201)


$string['about'] = 'O tomto editoru';
$string['absbottom'] = 'pln dol (absbottom)';
$string['address'] = 'Adresa';
$string['alertnoselectedtext'] = 'Nejprve je teba vybrat text!';
$string['alignment'] = 'Zarovnn';
$string['alternatetext'] = 'Alternativn text';
$string['anchorhelp'] = 'Tmto vytvte pouze nvt. Stle sem muste run nadefinovat odkaz.';
$string['anchorname'] = 'Nzev nvt';
$string['anchors'] = 'Nvt';
$string['baseline'] = 'a (baseline)';
$string['bold'] = 'Tun';
$string['borderthickness'] = 'Tlouka ohranien';
$string['bottom'] = 'Dol (bottom)';
$string['browse'] = 'Prochzet';
$string['cancel'] = 'Storno';
$string['cellpadding'] = 'Vnitn okraj bunk';
$string['cellspacing'] = 'Vzdlenost mezi bukami';
$string['choosechar'] = 'Vyberte znak';
$string['chooseicon'] = 'Vyberte ikonu k vloen';
$string['close'] = 'Zavt';
$string['closeafterreplace'] = 'Zavt po nahrazen';
$string['cols'] = 'Sloupc';
$string['copy'] = 'Koprovat vbr';
$string['createanchor'] = 'Vytvoit nvt';
$string['createfolder'] = 'Vytvoit sloku';
$string['createlink'] = 'Vloit odkaz';
$string['cut'] = 'Vyjmout vbr';
$string['cutpastemozilla'] = 'Bohuel, pro vloen textu ze schrnky momentln nemete pout bnou klvesovou zkratku i dokonce tlatko Vloit. Toto chovn je zpsobeno bezpenostnm opatenm zabudovanm do nkterch verz prohle Mozilla a Firefox.<br /><br />Existuj zpsoby, jak toto chovn obejt, take vyzkouejte:<br />(1) Msto CTRL+v zkuste zkratku SHIFT+Insert<br />(2) Pouijte nabdku pravy->Vloit v menu vaeho prohlee<br />(3) Upravte si nastaven vaeho prohlee v souboru user.js<br />(4) Na Linuxu zkuste vloit text pomoc nastavenho tlatka myi<br /><br />Pro vce informac kliknte na tlatko OK, pro nvrat do editoru stisknte Cancel, Storno i Zruit.';
$string['delete'] = 'Odstranit';
$string['filebrowser'] = 'Prohle soubor';
$string['findwhat'] = 'Najt';
$string['fontname'] = 'Nzev psma';
$string['fontsize'] = 'Velikost psma';
$string['forecolor'] = 'Barva psma';
$string['formatblock'] = 'Formt';
$string['fullscreen'] = 'Na celou obrazovku';
$string['heading'] = 'Nadpis';
$string['height'] = 'Vka';
$string['hilitecolor'] = 'Barva zvraznn';
$string['horizontal'] = 'Vodorovn';
$string['horizontalrule'] = 'Vodorovn ra';
$string['htmlmode'] = 'Pepnout na HTML zdroj';
$string['imageurl'] = 'URL obrzku';
$string['indent'] = 'Zvtit odsazen';
$string['insertchar'] = 'Vloit specln znak';
$string['insertimage'] = 'Vloit obrzek';
$string['insertlink'] = 'Vloit odkaz';
$string['insertsmile'] = 'Vloit smajlk';
$string['inserttable'] = 'Vloit tabulku';
$string['italic'] = 'Kurzva';
$string['itemsreplaced'] = 'vskyt nahrazeno!';
$string['justifycenter'] = 'Zarovnat na sted';
$string['justifyfull'] = 'Zarovnat do bloku';
$string['justifyleft'] = 'Zarovnat vlevo';
$string['justifyright'] = 'Zarovnat vpravo';
$string['layout'] = 'Vzhled';
$string['left'] = 'Vlevo';
$string['lefttoright'] = 'Zleva doprava';
$string['linkproperties'] = 'Vlastnosti odkazu';
$string['linktarget'] = 'Kde otevt';
$string['linktargetblank'] = 'V novm okn';
$string['linktargetnone'] = 'Bez uren';
$string['linktargetother'] = 'Jinde (zatm nefunguje)';
$string['linktargetself'] = 'Ve stvajcm rmci';
$string['linktargettop'] = 'Ve stejnm okn';
$string['linktitle'] = 'Titulek';
$string['linkurl'] = 'URL';
$string['matchcase'] = 'Rozliovat velikost';
$string['middle'] = 'Uprosted (middle)';
$string['minimize'] = 'Minimalizovat editor';
$string['move'] = 'Pesunout';
$string['nolink'] = 'Zabrnit automatickmu vytven odkaz';
$string['normal'] = 'Normln';
$string['notimage'] = 'Vybran soubor nen obrzek. Prosm, vyberte jin soubor.';
$string['notset'] = 'Nenastaveno';
$string['ok'] = 'OK';
$string['options'] = 'Volby';
$string['orderedlist'] = 'slovan seznam';
$string['outdent'] = 'Zmenit odsazen';
$string['paste'] = 'Vloit ze schrnky';
$string['path'] = 'HTML cesta';
$string['percent'] = 'Procent';
$string['pixels'] = 'Pixel';
$string['popupeditor'] = 'Zvtit editor';
$string['preformatted'] = 'Pedformtovan';
$string['preview'] = 'Nhled';
$string['properties'] = 'Vlastnosti';
$string['redo'] = 'Opakovat posledn akci';
$string['regularexpressions'] = 'Pouij regulrn vrazy';
$string['removelink'] = 'Odstranit odkaz';
$string['rename'] = 'Pejmenovat';
$string['replaceall'] = 'Nahradit ve';
$string['replacewith'] = 'Nahradit';
$string['right'] = 'Vpravo';
$string['righttoleft'] = 'Zprava doleva';
$string['rows'] = 'dk';
$string['searchandreplace'] = 'Najt a nahradit';
$string['searchnotfound'] = 'Hledan etzec nebyl nalezen!';
$string['selectcolor'] = 'Vbr barvy';
$string['selection'] = 'Vbr';
$string['showhelp'] = 'Npovda k pouvn editoru';
$string['size'] = 'Velikost';
$string['spacing'] = 'Vzdlenost od textu';
$string['strikethrough'] = 'Pekrtnout';
$string['subscript'] = 'Doln index';
$string['superscript'] = 'Horn index';
$string['textindicator'] = 'Stvajc styl';
$string['textmode'] = 'Jste v TEXTOVM reimu. Stisknutm tlatka [<>] se vrtte do reimu WYSIWYG.';
$string['texttop'] = 'Text nahoe (texttop)';
$string['top'] = 'Nahoru (top)';
$string['type'] = 'Typ';
$string['underline'] = 'Podtrhnout';
$string['undo'] = 'Vrtit posledn akci (UNDO)';
$string['unorderedlist'] = 'Odrkov seznam';
$string['upload'] = 'Nahrt';
$string['vertical'] = 'Svisle';
$string['width'] = 'ka';
$string['wordclean'] = 'Vyistit HTML z Wordu';
$string['zip'] = 'ZIP';

?>
